#!/usr/bin/python
# -*- coding: UTF-8 -*-
"""
excel xls 文件读取
@author:zhaojiajun
@file:excel_util.py
@time:2022/07/27
"""
import sys

import xlrd
import os


def read_xls(file_path, sheet_name) -> []:
    """
    读取.xls文件
    此函数将文件中每行内容转成字典，字典的key是列名，放于字典中
    :param file_path:
    :param sheet_name
    :return:
    """
    data = []
    try:
        # 检查文件是否存在
        if not os.path.exists(file_path):
            return []
        book = xlrd.open_workbook(file_path)
        # 检查sheet是否存在
        if sheet_name not in book.sheet_names():
            return []
        sheet = book.sheet_by_name(sheet_name)
        rows = sheet.nrows
        columns = sheet.ncols
        for row_index in range(1, rows):
            tmp_dict = {}
            row = sheet.row(row_index)
            for col_index in range(0, columns):
                key = sheet.col_values(col_index, 0, 1)[0]
                value = row[col_index].value
                tmp_dict[key] = value
            data.append(tmp_dict)
    finally:
        return data


if __name__ == '__main__':
    x = read_xls('/Users/zhaojiajun/Desktop/test_auto.xls', 'Sheet1')
    y = 1



#!/usr/bin/python
# -*- coding: UTF-8 -*-
"""
时间处理工具模块

@author:zhaojiajun
@file:time_util.py
@time:2022/07/12
"""
import time


def get_current_time(time_format: str):
    """
    获取当前时间
    :param time_format: 时间格式
    :return:
    """
    return time.strftime(time_format, time.localtime())


if __name__ == '__main__':
    print(get_current_time())



#!/usr/bin/python
# -*- coding: UTF-8 -*-
"""
自动化测试相关的用户自定义异常

@author:zhaojiajun
@file:auto_exception.py
@time:2022/07/12
"""


class TestMethodsFileNotFoundException(Exception):

    def __init__(self, file_path: str):
        super().__init__(self)
        self.file_path = file_path

    def __str__(self):
        return '记录需要执行的测试方法文件不存在{}'.format(self.file_path)


if __name__ == '__main__':
    pass



#!/usr/bin/python
# -*- coding: UTF-8 -*-
"""
@author:zhaojiajun
@file:__init__.py.py
@time:2022/07/11
"""

__all__ = ['file_util', 'time_util', 'excel_util', 'json_util']

if __name__ == '__main__':
    pass



#!/usr/bin/python
# -*- coding: UTF-8 -*-
"""
json 处理工具

@author:zhaojiajun
@file:json_util.py
@time:2022/07/28
"""

from deepdiff import DeepDiff, grep

global ignore_value_path_list
ignore_value_path_list = []

global ignore_path_list
ignore_path_list = []

IGNORE_VALUE_STR = "${__ignore_value__}"
IGNORE_STR = "{__ignore__}"


def filter_removed_item(src, tar):
    """
    使用tar对src进行过滤，
    :param src:原始列表
    :param tar:目标列表
    :return: 返回过滤后的列表
    """
    return list(filter(lambda item: item not in src, tar))


def is_same_json(src, tar):
    """
    对比两个json对象

    ${__ignore__}: 在对比时，会忽略此内容的对比，不仅忽略值，而且对应key是否存在都不关系，属于完全忽略
    ${__ignore_value__}: 在对比时，忽略值的不一致，但是key和value必须存在

    :param src:
    :param tar:
    :return: 返回对比结果和对比明细
    """
    global ignore_value_path_list
    global ignore_path_list
    # 查找${__ignore_value__}
    search_result = src | grep(IGNORE_VALUE_STR)
    ignore_value_path_list = search_result['matched_values'] if 'matched_values' in search_result.keys() else []
    # 查找${__ignore__}
    search_result = src | grep(IGNORE_STR)
    ignore_path_list = search_result[
        'matched_values'] if 'matched_values' in search_result.keys() else []

    # 对比，得到对比结果
    detail = DeepDiff(src, tar, exclude_paths=ignore_path_list,
                      ignore_type_in_groups=[DeepDiff.strings, DeepDiff.numbers])

    # 对比结果中的dictionary_item_removed相关内容处理
    # 使用ignore_value_path_list对dictionary_item_removed的结果进行过滤,如果后如果还存在内容，说明存在异常，tar存在缺失
    if detail and "dictionary_item_removed" in detail.keys():
        dictionary_item_removed = detail['dictionary_item_removed']
        filter_result = filter_removed_item(list(filter(lambda item: str(item), dictionary_item_removed)),
                                            ignore_value_path_list)
        if filter_result:
            # 如果过滤后，还存在内容，则重置detail中的dictionary_item_removed内容，剔除了${__ignore_value__}的内容
            detail['dictionary_item_removed'] = filter_result

    # 对比结果中的values_changed相关内容处理
    if detail and "values_changed" in detail.keys():
        ignore_values_changed_list = list(filter(lambda item: item[1]['old_value'] == IGNORE_VALUE_STR,
                                                 detail['values_changed'].items()))
        # 删除掉需要忽略的值变动
        [value for value in
         map(lambda index: detail['values_changed'].pop(index) if detail['values_changed'].get(index) else None,
             [item[0] for item in ignore_values_changed_list])]

    # 对比结果中的type_changes相关内容处理，因为在src中${__ignore_value__}是个字符串，tar中有可能不是字符串，所以这里需要排除
    if detail and "type_changes" in detail.keys():
        ignore_type_changed_list = list(filter(lambda item: item[1]['old_value'] == IGNORE_VALUE_STR,
                                                 detail['type_changes'].items()))
        # 删除掉需要忽略的类型变动
        [value for value in
         map(lambda index: detail['type_changes'].pop(index) if detail['type_changes'].get(index) else None,
             [item[0] for item in ignore_type_changed_list])]

    # 重置结果：清除空的内容
    detail.remove_empty_keys()
    # 返回对比结果
    result = False if detail else True
    return result, detail


if __name__ == '__main__':
    json_1 = {"key1": 123, "key2": "${__ignore__}", "key3": "${__ignore_value__}"}
    json_2 = {"key1": 123, "key2": "test", "key3": 123}

    print(is_same_json(json_1, json_2))



#!/usr/bin/python
# -*- coding: UTF-8 -*-
"""
文件处理模块

@author:zhaojiajun
@file:file_util.py
@time:2022/07/11
"""
import os
from auto_doraemon.user_defined_exception.auto_exception import TestMethodsFileNotFoundException


def write_file(file_path: str, file_name: str, content: str):
    """
    想文件中写入指定内容
    写入内容之前，如果文件已经存在，会先删除并重新创建文件
    :param file_path:文件路径
    :param file_name:文件名字
    :param content:内容
    :return:
    """
    if not os.path.exists(file_path):
        os.makedirs(file_path, exist_ok=True)
    path = os.path.join(file_path, file_name)
    if os.path.exists(path):
        os.remove(path)
    with open(path, 'w+') as file:
        file.write(content)


def read_file(file_path: str):
    """
    读取文件中的内容
    :param file_path: 文件路径
    :return:
    """
    if not os.path.isfile(file_path) and not os.path.exists(file_path):
        raise TestMethodsFileNotFoundException(file_path)
    with open(file_path, 'r') as file:
        content = file.read()
    return content


if __name__ == '__main__':
    write_file('', 'test.json', '1234')



#!/usr/bin/python
# -*- coding: UTF-8 -*-
"""
打包模块
@author:zhaojiajun
@file:setup.py
@time:2022/07/11
"""

from setuptools import setup, find_packages

__version__ = '1.0.5'
__name__ = 'autodoraemon'

require_packages = [
    "setuptools==47.1.0",
    "requests==2.25.1",
    "xlrd==2.0.1",
    "deepdiff==5.8.1"
]

setup(
    name=__name__,
    version=__version__,
    description='自动化测试辅助测试项目，主要提供工具函数',
    author='zhaojiajun',
    author_email='zhaojiajun@baicizhan.com',
    packages=find_packages(),
    install_requires=require_packages
)
